---
description: T.A.R.B.S. Engine Beta v1.0
---

# Welcome

## T.A.R.B.S. Engine Alpha

T.A.R.B.S. Engine is a small project I'm working on out of pure boredom and for practice. It is a text based game engine for python3.

[![CodeFactor](https://www.codefactor.io/repository/github/tman540/t.a.r.b.s.-engine/badge)](https://www.codefactor.io/repository/github/tman540/t.a.r.b.s.-engine) ![MadeWithPython](https://img.shields.io/badge/Made%20with-Python-blue.svg) ![Version](https://img.shields.io/badge/Version-Beta%201.0-a620df.svg)

Notable Features:

* Python3 Support
* Easy to Use
* Very little limitation
* Cross platform!
* Useful debugging functionality

[Download ](https://github.com/tman540/T.A.R.B.S.-Engine/releases)- Latest Release: Beta 1.0

`pip install T.A.R.B.S.-Engine`

Open the repository [here](https://github.com/tman540/T.A.R.B.S.-Engine).

This [documentation ](https://tarbs.tautonico.tech)will contain:

* A quick start guide 
* In-depth documentation on the entire engine 
* Examples

**Check the table of contents for links to every part**

